@@ -416,7 +416,7 @@ class Columns:
         np.savez(
             outfile,
             arrays = self.arrays,
-            metadata = self.metadata,
+            metadata = dict(self.metadata, svj_ntuple_processing_version=version()),
             cutflow_keys = cutflow_keys,
             cutflow_vals = cutflow_vals
             )
